==> sca-patterns-sle15-1.5.5.tar.gz: sca-patterns-sle15-1.5.5/patterns/SLE/sle15sp4/webkit2gtk3_SUSE-SU-2022_3137-1_sles_15.4.py <==
#!/usr/bin/python3
#
# Title:       Important Security Announcement for webkit2gtk3 SUSE-SU-2022:3137-1
# Description: Security fixes for SUSE Linux Enterprise 15 SP4
# URL:         https://lists.suse.com/pipermail/sle-security-updates/2022-September/012158.html
# Source:      Security Announcement Generator (sagen.py) v2.0.0-beta4
# Modified:    2022 Oct 25
#
##############################################################################
# Copyright (C) 2022 SUSE LLC
##############################################################################
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; version 2 of the License.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, see <http://www.gnu.org/licenses/>.
#
#  Authors/Contributors:
#   Jason Record <jason.record@suse.com>
#
##############################################################################

import os
import Core
import SUSE

META_CLASS = "Security"
META_CATEGORY = "SLE"
META_COMPONENT = "webkit2gtk3"
pattern_filename = os.path.basename(__file__)
PRIMARY_LINK = "META_LINK_Security"
OVERALL = Core.TEMP
OVERALL_INFO = "NOT SET"
OTHER_LINKS = "META_LINK_Security=https://lists.suse.com/pipermail/sle-security-updates/2022-September/012158.html"
Core.init(META_CLASS, META_CATEGORY, META_COMPONENT, pattern_filename, PRIMARY_LINK, OVERALL, OVERALL_INFO, OTHER_LINKS)

LTSS = False
NAME = 'webkit2gtk3'
MAIN = ''
SEVERITY = 'Important'
TAG = 'SUSE-SU-2022:3137-1'
PACKAGES = {}
SERVER = SUSE.getHostInfo()

if ( SERVER['DistroVersion'] == 15):
	if ( SERVER['DistroPatchLevel'] == 4 ):
		PACKAGES = {
			'libjavascriptcoregtk-4_0-18': '2.36.7-150400.4.12.1',
			'libjavascriptcoregtk-4_0-18-debuginfo': '2.36.7-150400.4.12.1',
			'libwebkit2gtk-4_0-37': '2.36.7-150400.4.12.1',
			'libwebkit2gtk-4_0-37-debuginfo': '2.36.7-150400.4.12.1',
			'typelib-1_0-JavaScriptCore-4_0': '2.36.7-150400.4.12.1',
			'typelib-1_0-WebKit2-4_0': '2.36.7-150400.4.12.1',
			'typelib-1_0-WebKit2WebExtension-4_0': '2.36.7-150400.4.12.1',
			'webkit2gtk-4_0-injected-bundles': '2.36.7-150400.4.12.1',
			'webkit2gtk-4_0-injected-bundles-debuginfo': '2.36.7-150400.4.12.1',
			'webkit2gtk3-soup2-debugsource': '2.36.7-150400.4.12.1',
			'webkit2gtk3-soup2-devel': '2.36.7-150400.4.12.1',
		}
		SUSE.securityAnnouncementPackageCheck(NAME, MAIN, LTSS, SEVERITY, TAG, PACKAGES)
	else:
		Core.updateStatus(Core.ERROR, "ERROR: " + NAME + " Security Announcement: Outside the service pack scope")
else:
	Core.updateStatus(Core.ERROR, "ERROR: " + NAME + " Security Announcement: Outside the distribution scope")
Core.printPatternResults()

==> sca-patterns-sle15-1.5.8.tar.gz: sca-patterns-sle15-1.5.8/patterns/SLE/sle15sp4/webkit2gtk3_SUSE-SU-2022_2523-1_sles_15.4.py <==
#!/usr/bin/python3
#
# Title:       Important Security Announcement for webkit2gtk3 SUSE-SU-2022:2523-1
# Description: Security fixes for SUSE Linux Enterprise 15 SP4
# URL:         https://lists.suse.com/pipermail/sle-security-updates/2022-July/011628.html
# Source:      Security Announcement Generator (sagen.py) v2.0.0-beta4
# Modified:    2022 Oct 25
#
##############################################################################
# Copyright (C) 2022 SUSE LLC
##############################################################################
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; version 2 of the License.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, see <http://www.gnu.org/licenses/>.
#
#  Authors/Contributors:
#   Jason Record <jason.record@suse.com>
#
##############################################################################

import os
import Core
import SUSE

META_CLASS = "Security"
META_CATEGORY = "SLE"
META_COMPONENT = "webkit2gtk3"
pattern_filename = os.path.basename(__file__)
PRIMARY_LINK = "META_LINK_Security"
OVERALL = Core.TEMP
OVERALL_INFO = "NOT SET"
OTHER_LINKS = "META_LINK_Security=https://lists.suse.com/pipermail/sle-security-updates/2022-July/011628.html"
Core.init(META_CLASS, META_CATEGORY, META_COMPONENT, pattern_filename, PRIMARY_LINK, OVERALL, OVERALL_INFO, OTHER_LINKS)

LTSS = False
NAME = 'webkit2gtk3'
MAIN = ''
SEVERITY = 'Important'
TAG = 'SUSE-SU-2022:2523-1'
PACKAGES = {}
SERVER = SUSE.getHostInfo()

if ( SERVER['DistroVersion'] == 15):
	if ( SERVER['DistroPatchLevel'] == 4 ):
		PACKAGES = {
			'libjavascriptcoregtk-4_0-18': '2.36.4-150400.4.6.2',
			'libjavascriptcoregtk-4_0-18-debuginfo': '2.36.4-150400.4.6.2',
			'libwebkit2gtk-4_0-37': '2.36.4-150400.4.6.2',
			'libwebkit2gtk-4_0-37-debuginfo': '2.36.4-150400.4.6.2',
			'typelib-1_0-JavaScriptCore-4_0': '2.36.4-150400.4.6.2',
			'typelib-1_0-WebKit2-4_0': '2.36.4-150400.4.6.2',
			'typelib-1_0-WebKit2WebExtension-4_0': '2.36.4-150400.4.6.2',
			'webkit2gtk-4_0-injected-bundles': '2.36.4-150400.4.6.2',
			'webkit2gtk-4_0-injected-bundles-debuginfo': '2.36.4-150400.4.6.2',
			'webkit2gtk3-soup2-debugsource': '2.36.4-150400.4.6.2',
			'webkit2gtk3-soup2-devel': '2.36.4-150400.4.6.2',
		}
		SUSE.securityAnnouncementPackageCheck(NAME, MAIN, LTSS, SEVERITY, TAG, PACKAGES)
	else:
		Core.updateStatus(Core.ERROR, "ERROR: " + NAME + " Security Announcement: Outside the service pack scope")
else:
	Core.updateStatus(Core.ERROR, "ERROR: " + NAME + " Security Announcement: Outside the distribution scope")
Core.printPatternResults()
